==> haskell-hls-code-range-plugin-2.1.0.0-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-code-range-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-code-range-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-code-range-plugin-2.1.0.0-FIL1Ja5HHAC849Y32zHh3R
key:                  hls-code-range-plugin-2.1.0.0-FIL1Ja5HHAC849Y32zHh3R
license:              Apache-2.0
maintainer:           kokobd
author:               kokobd
synopsis:
    HLS Plugin to support smart selection range and Folding range

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  6f38ebf73267c7977ec4ae41ab9c387a
exposed:              True
exposed-modules:      Ide.Plugin.CodeRange Ide.Plugin.CodeRange.Rules
hidden-modules:       Ide.Plugin.CodeRange.ASTPreProcess
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-code-range-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-code-range-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-code-range-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-code-range-plugin
hs-libraries:         HShls-code-range-plugin-2.1.0.0-FIL1Ja5HHAC849Y32zHh3R
depends:
    aeson-2.1.2.1-LDc25PpdH5WHlLB8Mcp2Rh base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 extra-1.7.16-EVqIvjfjup2KjWh1SyzBng
    ghcide-2.1.0.0-1ZBBrI7K4NbIF99YfBQXnD
    hashable-1.4.4.0-85lkkmOSRZHDIzkr9EkKNp
    hls-plugin-api-2.1.0.0-7rhIWwjx59aGSCVhjvAuPR
    lens-5.3.1-3FYsDpCHEKEBLMSbQ9nAqF
    lsp-2.1.0.0-DyFP5ixOoJMD0lbV6POXwv mtl-2.2.2
    semigroupoids-6.0.1-HojjKCFNEldAzPbwF6sStW text-2.0.2
    transformers-0.5.6.2 vector-0.13.2.0-3jopdCx3MMLHVSrvHoDH9i

haddock-interfaces:
    /usr/share/doc/haskell-hls-code-range-plugin/html/hls-code-range-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-code-range-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-code-range-plugin-2.1.0.0-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-code-range-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-code-range-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-code-range-plugin-2.1.0.0-9l5AQZoR8dFIqZzo6MxSa7
key:                  hls-code-range-plugin-2.1.0.0-9l5AQZoR8dFIqZzo6MxSa7
license:              Apache-2.0
maintainer:           kokobd
author:               kokobd
synopsis:
    HLS Plugin to support smart selection range and Folding range

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  aad131773619baf6ea97a68b0f2fa4df
exposed:              True
exposed-modules:      Ide.Plugin.CodeRange Ide.Plugin.CodeRange.Rules
hidden-modules:       Ide.Plugin.CodeRange.ASTPreProcess
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-code-range-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-code-range-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-code-range-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-code-range-plugin
hs-libraries:         HShls-code-range-plugin-2.1.0.0-9l5AQZoR8dFIqZzo6MxSa7
depends:
    aeson-2.1.2.1-LDc25PpdH5WHlLB8Mcp2Rh base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 extra-1.7.16-EVqIvjfjup2KjWh1SyzBng
    ghcide-2.1.0.0-8jnnfJ4RKuOD3t6pqSmFx7
    hashable-1.4.4.0-85lkkmOSRZHDIzkr9EkKNp
    hls-plugin-api-2.1.0.0-AFhcJJUimcp2MwiB53NadQ
    lens-5.3.1-3FYsDpCHEKEBLMSbQ9nAqF
    lsp-2.1.0.0-DyFP5ixOoJMD0lbV6POXwv mtl-2.2.2
    semigroupoids-6.0.1-HojjKCFNEldAzPbwF6sStW text-2.0.2
    transformers-0.5.6.2 vector-0.13.2.0-3jopdCx3MMLHVSrvHoDH9i

haddock-interfaces:
    /usr/share/doc/haskell-hls-code-range-plugin/html/hls-code-range-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-code-range-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
